@@ -65,6 +65,9 @@ import javax.mail.FolderClosedException;
 import javax.mail.MessagingException;
 import javax.mail.StoreClosedException;
 import org.slf4j.Logger;
+import com.openexchange.config.cascade.ConfigProperty;
+import com.openexchange.config.cascade.ConfigView;
+import com.openexchange.config.cascade.ConfigViewFactory;
 import com.openexchange.exception.Category;
 import com.openexchange.exception.OXException;
 import com.openexchange.folderstorage.FolderService;
@@ -307,6 +310,19 @@ public class IMAPDefaultFolderChecker {
         MailSessionCache cache = MailSessionCache.getInstance(session);
         String key = MailSessionParameterNames.getParamDefaultFolderChecked();
         if (!isDefaultFoldersChecked(key, cache)) {
+
+            /*-
+             * ----------------------------------------------------------- NOTE -----------------------------------------------------------
+             *
+             * In case there are switching standard folder; e.g. change from next to INBOX to below INBOX.
+             * Please check for following prominent WARN logging:
+             *   "NAMESPACE from IMAP server <imap-host> indicates to use root level for login <imap-login>, but IMAP server denies to create such folders!"
+             *
+             * This hints to a failed probe whether IMAP server allows to create folders on root level; see IMAPCommandsCollection.canCreateSubfolder()
+             *
+             * ----------------------------------------------------------------------------------------------------------------------------
+             */
+
             Lock lock = getSessionLock();
             lock.lock();
             try {
@@ -320,7 +336,19 @@ public class IMAPDefaultFolderChecker {
                         IMAPFolder inboxFolder;
                         {
                             IMAPFolder tmp = (IMAPFolder) imapStore.getFolder(INBOX);
-                            ListLsubEntry entry = ListLsubCache.getCachedLISTEntry(INBOX, accountId, tmp, session, ignoreSubscription, true);
+
+                            /*
+                             * Bug #41825: Changed the handling of special-use folders.
+                             *
+                             * Now special-use folder used only when creating a new mail account to
+                             * initial fill the default folder fields.
+                             *
+                             * After that the values within the database are used instead. Therefore
+                             * changes to the database now influence the default folders.
+                             */
+                            boolean reinitSpecialUseIfLoaded = false;
+                            ListLsubEntry entry = ListLsubCache.getCachedLISTEntry(INBOX, accountId, tmp, session, ignoreSubscription, reinitSpecialUseIfLoaded);
+
                             if (entry.exists()) {
                                 inboxFolder = tmp;
                             } else {
@@ -395,7 +423,14 @@ public class IMAPDefaultFolderChecker {
         }
     }
 
+    private static ListLsubEntry getByNameOrFullName(boolean isPrimary, int index, String[] names, String[] fullNames, Collection<ListLsubEntry> entries) {
+        return isPrimary ? getByName(names[index], entries) : getByFullName(fullNames[index], entries);
+    }
+
     private static ListLsubEntry getByName(String name, Collection<ListLsubEntry> entries) {
+        if (entries.isEmpty()) {
+            return null;
+        }
         if (null == name) {
             // First one
             return entries.iterator().next();
@@ -410,6 +445,9 @@ public class IMAPDefaultFolderChecker {
     }
 
     private static ListLsubEntry getByFullName(String fullName, Collection<ListLsubEntry> entries) {
+        if (entries.isEmpty()) {
+            return null;
+        }
         if (null == fullName) {
             // First one
             return entries.iterator().next();
@@ -441,7 +479,7 @@ public class IMAPDefaultFolderChecker {
             int size = entries.size();
             if (size > 0) {
                 // Determine the SPECIAL-USE entry to use
-                ListLsubEntry entry = size == 1 ? entries.iterator().next() : (MailAccount.DEFAULT_ID == accountId ? getByName(names[index], entries) : getByFullName(fullNames[index], entries));
+                ListLsubEntry entry = size == 1 ? entries.iterator().next() : getByNameOrFullName(MailAccount.DEFAULT_ID == accountId, index, names, fullNames, entries);
 
                 // Check entry
                 ListLsubEntry cached = ListLsubCache.getCachedLISTEntry(entry.getFullName(), accountId, imapStore, session, ignoreSubscription);
@@ -463,6 +501,70 @@ public class IMAPDefaultFolderChecker {
         return null;
     }
 
+    /**
+     * Gets the SPECIAL-USE information for the connected IMAP store.
+     *
+     * @param names The expected standard folder names
+     * @param fullNames The expected standard folder full names
+     * @return The SPECIAL-USE information
+     * @throws OXException If SPECIAL-USE information cannot be returned
+     */
+    protected TIntObjectMap<String> getSpecialUseInfo(String[] names, String[] fullNames) throws OXException {
+        try {
+            TIntObjectMap<String> indexes = new TIntObjectHashMap<String>(6);
+            IMAPFolder imapFolder = (IMAPFolder) imapStore.getFolder(INBOX);
+            boolean isPrimary = MailAccount.DEFAULT_ID == accountId;
+
+            // Entries with "\Drafts" marker
+            Collection<ListLsubEntry> entries = ListLsubCache.getDraftsEntry(accountId, imapFolder, session, ignoreSubscription);
+            int size = entries.size();
+            if (size > 0) {
+                int index = StorageUtility.INDEX_DRAFTS;
+                ListLsubEntry entry = size == 1 ? entries.iterator().next() : getByNameOrFullName(isPrimary, index, names, fullNames, entries);
+                if (null != entry) {
+                    indexes.put(index, entry.getFullName());
+                }
+            }
+
+            // Entries with "\Junk" marker
+            entries = ListLsubCache.getJunkEntry(accountId, imapFolder, session, ignoreSubscription);
+            size = entries.size();
+            if (size > 0) {
+                int index = StorageUtility.INDEX_SPAM;
+                ListLsubEntry entry = size == 1 ? entries.iterator().next() : getByNameOrFullName(isPrimary, index, names, fullNames, entries);
+                if (null != entry) {
+                    indexes.put(index, entry.getFullName());
+                }
+            }
+
+            // Entries with "\Send" marker
+            entries = ListLsubCache.getSentEntry(accountId, imapFolder, session, ignoreSubscription);
+            size = entries.size();
+            if (size > 0) {
+                int index = StorageUtility.INDEX_SENT;
+                ListLsubEntry entry = size == 1 ? entries.iterator().next() : getByNameOrFullName(isPrimary, index, names, fullNames, entries);
+                if (null != entry) {
+                    indexes.put(index, entry.getFullName());
+                }
+            }
+
+            // Entries with "\Trash" marker
+            entries = ListLsubCache.getTrashEntry(accountId, imapFolder, session, ignoreSubscription);
+            size = entries.size();
+            if (size > 0) {
+                int index = StorageUtility.INDEX_TRASH;
+                ListLsubEntry entry = size == 1 ? entries.iterator().next() : getByNameOrFullName(isPrimary, index, names, fullNames, entries);
+                if (null != entry) {
+                    indexes.put(index, entry.getFullName());
+                }
+            }
+
+            return indexes;
+        } catch (MessagingException e) {
+            throw MimeMailException.handleMessagingException(e, imapConfig, session);
+        }
+    }
+
     /**
      * Checks for each standard folder sequentially.
      *
@@ -490,78 +592,72 @@ public class IMAPDefaultFolderChecker {
         String[] names = defaultFolderNamesProvider.getDefaultFolderNames(imapConfig, isSpamOptionEnabled);
         SpamHandler spamHandler = isSpamOptionEnabled ? SpamHandlerRegistry.getSpamHandlerBySession(session, accountId) : NoSpamHandler.getInstance();
 
-        // Check for marked default folders
-        TIntObjectMap<String> checkedIndexes = new TIntObjectHashMap<String>(6);
-        try {
-            IMAPFolder imapFolder = (IMAPFolder) imapStore.getFolder(INBOX);
+        // Collect SPECIAL-USE information
+        TIntObjectMap<String> specialUseInfo = getSpecialUseInfo(names, fullNames);
+        TIntObjectMap<String> indexes = null;
 
-            // Entries with "\Drafts" marker
-            Collection<ListLsubEntry> entries = ListLsubCache.getDraftsEntry(accountId, imapFolder, session, ignoreSubscription);
-            handleMarkedEntries(entries, StorageUtility.INDEX_DRAFTS, names, fullNames, checkedIndexes, cache, modified);
+        // Check if it is the first connect attempt for primary mail account
+        if (MailAccount.DEFAULT_ID == accountId) {
+            boolean checkSpecialUseFolder = false;
+            ConfigViewFactory viewFactory = Services.getService(ConfigViewFactory.class);
+            if (viewFactory != null) {
+                ConfigView view = viewFactory.getView(session.getUserId(), session.getContextId());
+                ConfigProperty<Boolean> prop = view.property("user", "com.openexchange.mail.specialuse.check", Boolean.class);
+                if (prop.isDefined()) {
+                    Boolean b = prop.get();
+                    checkSpecialUseFolder = null != b && b.booleanValue();
+                    prop.set(null);
+                }
+            }
 
-            // Entries with "\Junk" marker
-            entries = ListLsubCache.getJunkEntry(accountId, imapFolder, session, ignoreSubscription);
-            handleMarkedEntries(entries, StorageUtility.INDEX_SPAM, names, fullNames, checkedIndexes, cache, modified);
-
-            // Entries with "\Send" marker
-            entries = ListLsubCache.getSentEntry(accountId, imapFolder, session, ignoreSubscription);
-            handleMarkedEntries(entries, StorageUtility.INDEX_SENT, names, fullNames, checkedIndexes, cache, modified);
-
-            // Entries with "\Trash" marker
-            entries = ListLsubCache.getTrashEntry(accountId, imapFolder, session, ignoreSubscription);
-            handleMarkedEntries(entries, StorageUtility.INDEX_TRASH, names, fullNames, checkedIndexes, cache, modified);
-        } catch (MessagingException e) {
-            throw MimeMailException.handleMessagingException(e, imapConfig, session);
+            if (checkSpecialUseFolder) {
+                // Check for marked default folders on first connect attempt for primary mail account
+                indexes = specialUseInfo;
+            }
         }
 
         // Sanitize given names and full-names against mail account settings
-        sanitizeAgainstMailAccount(names, fullNames, namespace, sep, checkedIndexes, accountChanged);
+        sanitizeAgainstMailAccount(names, fullNames, namespace, sep, indexes, accountChanged);
 
         // Check folders
         TIntObjectMap<String> toSet = (MailAccount.DEFAULT_ID == accountId) ? null : new TIntObjectHashMap<String>(6);
         boolean added = false;
         for (int index = 0; index < names.length; index++) {
-            String preCheckedFullName = checkedIndexes.get(index);
-            if (null == preCheckedFullName) {
-                String checkedFullName = null;
+            String checkedFullName = null;
 
-                // Determine the checked full name
-                {
-                    // Get desired name and full name --> full name dominates name
-                    String name = names[index];
-                    String fullName = fullNames[index];
-                    LOG.debug("Standard folder check for {} with name={} and fullName={} for account {} (user={}, context={})", getFallbackName(index), null == name ? "null" : name, null == fullName ? "null" : fullName, Integer.valueOf(accountId), Integer.valueOf(session.getUserId()), Integer.valueOf(session.getContextId()));
+            // Determine the checked full name
+            {
+                // Get desired name and full name --> full name dominates name
+                String name = names[index];
+                String fullName = fullNames[index];
+                LOG.debug("Standard folder check for {} with name={} and fullName={} for account {} (user={}, context={})", getFallbackName(index), null == name ? "null" : name, null == fullName ? "null" : fullName, Integer.valueOf(accountId), Integer.valueOf(session.getUserId()), Integer.valueOf(session.getContextId()));
 
-                    // Check folder & return its full name
-                    if (StorageUtility.INDEX_CONFIRMED_HAM == index) {
-                        if (spamHandler.isCreateConfirmedHam()) {
-                            checkedFullName = checkFullNameFor(index, namespace, fullName, name, sep, type, spamHandler.isUnsubscribeSpamFolders() ? 0 : -1, modified, accountChanged);
-                        } else {
-                            LOG.debug("Skipping check for {} due to SpamHandler.isCreateConfirmedHam()=false", name);
-                        }
-                    } else if (StorageUtility.INDEX_CONFIRMED_SPAM == index) {
-                        if (spamHandler.isCreateConfirmedSpam()) {
-                            checkedFullName = checkFullNameFor(index, namespace, fullName, name, sep, type, spamHandler.isUnsubscribeSpamFolders() ? 0 : -1, modified, accountChanged);
-                        } else {
-                            LOG.debug("Skipping check for {} due to SpamHandler.isCreateConfirmedSpam()=false", name);
-                        }
+                // Check folder & return its full name
+                if (StorageUtility.INDEX_CONFIRMED_HAM == index) {
+                    if (spamHandler.isCreateConfirmedHam()) {
+                        checkedFullName = checkFullNameFor(index, namespace, specialUseInfo, fullName, name, sep, type, spamHandler.isUnsubscribeSpamFolders() ? 0 : -1, modified, accountChanged);
                     } else {
-                        checkedFullName = checkFullNameFor(index, namespace, fullName, name, sep, type, 1, modified, accountChanged);
+                        LOG.debug("Skipping check for {} due to SpamHandler.isCreateConfirmedHam()=false", name);
                     }
-
-                    // Check against account data
-                    if ((null != toSet) && (null != checkedFullName) && (false == isEmpty(fullName)) && !checkedFullName.equals(fullName)) {
-                        toSet.put(index, checkedFullName);
-                        added = true;
+                } else if (StorageUtility.INDEX_CONFIRMED_SPAM == index) {
+                    if (spamHandler.isCreateConfirmedSpam()) {
+                        checkedFullName = checkFullNameFor(index, namespace, specialUseInfo, fullName, name, sep, type, spamHandler.isUnsubscribeSpamFolders() ? 0 : -1, modified, accountChanged);
+                    } else {
+                        LOG.debug("Skipping check for {} due to SpamHandler.isCreateConfirmedSpam()=false", name);
                     }
+                } else {
+                    checkedFullName = checkFullNameFor(index, namespace, specialUseInfo, fullName, name, sep, type, 1, modified, accountChanged);
                 }
 
-                // Set the checked full name
-                setDefaultMailFolder(index, checkedFullName, cache);
-            } else {
-                // For safety reason set pre-checked full name
-                setDefaultMailFolder(index, preCheckedFullName, cache);
+                // Check against account data
+                if ((null != toSet) && (null != checkedFullName) && (false == isEmpty(fullName)) && !checkedFullName.equals(fullName)) {
+                    toSet.put(index, checkedFullName);
+                    added = true;
+                }
             }
+
+            // Set the checked full name
+            setDefaultMailFolder(index, checkedFullName, cache);
         }
 
         // Update account data if necessary
@@ -604,14 +700,16 @@ public class IMAPDefaultFolderChecker {
                 String fullName = fullNames[i];
                 if (isEmpty(fullName)) {
                     // No full name given
-                    String expectedFullName = checkedIndexes.get(i);
-                    if (null != expectedFullName) {
-                        // Deduce expected name from SPECIAL-USE full name
-                        String expectedName = expectedFullName.substring(expectedFullName.lastIndexOf(sep) + 1);
-                        if (!expectedName.equals(names[i])) {
-                            LOG.warn("Replacing invalid name in settings of primary account. Should be \"{}\", but is \"{}\" (user={}, context={})", expectedName, names[i], Integer.valueOf(session.getUserId()), Integer.valueOf(session.getContextId()));
-                            names[i] = expectedName;
-                            namesToSet.put(i, expectedName);
+                    if (null != checkedIndexes) {
+                        String expectedFullName = checkedIndexes.get(i);
+                        if (null != expectedFullName) {
+                            // Deduce expected name from SPECIAL-USE full name
+                            String expectedName = expectedFullName.substring(expectedFullName.lastIndexOf(sep) + 1);
+                            if (!expectedName.equals(names[i])) {
+                                LOG.warn("Replacing invalid name in settings of primary account. Should be \"{}\", but is \"{}\" (user={}, context={})", expectedName, names[i], Integer.valueOf(session.getUserId()), Integer.valueOf(session.getContextId()));
+                                names[i] = expectedName;
+                                namesToSet.put(i, expectedName);
+                            }
                         }
                     }
                     fullNames[i] = null;
@@ -619,7 +717,11 @@ public class IMAPDefaultFolderChecker {
                     // Full name specified
                     if (fullName.indexOf(sep) > 0 || !fullName.equals(names[i])) {
                         // E.g. name=Sent, but fullName=INBOX/Sent or fullName=Zent
-                        String expectedFullName = checkedIndexes.get(i);
+
+                        String expectedFullName = null;
+                        if (null != checkedIndexes) {
+                            expectedFullName = checkedIndexes.get(i);
+                        }
                         if (null == expectedFullName) {
                             // Deduce expected full-name from namespace + name concatenation
                             expectedFullName = namespace + names[i];
@@ -661,7 +763,7 @@ public class IMAPDefaultFolderChecker {
                 }
             }
         } else {
-            if (!checkedIndexes.isEmpty()) {
+            if (null != checkedIndexes && !checkedIndexes.isEmpty()) {
                 TIntObjectMap<String> fullNamesToSet = new TIntObjectHashMap<String>(6);
                 TIntObjectMap<String> namesToSet = new TIntObjectHashMap<String>(6);
                 for (int i = 0; i < fullNames.length; i++) {
@@ -712,6 +814,7 @@ public class IMAPDefaultFolderChecker {
      *
      * @param index The index
      * @param namespace The personal namespace prefix
+     * @param specialUseInfo The SPECIAL-USE information
      * @param fullName The full name
      * @param name The name
      * @param sep The separator character
@@ -722,19 +825,19 @@ public class IMAPDefaultFolderChecker {
      * @return The checked full name
      * @throws OXException If an error occurs
      */
-    protected String checkFullNameFor(int index, String namespace, String fullName, String name, char sep, int type, int subscribe, BoolReference modified, BoolReference accountChanged) throws OXException {
+    protected String checkFullNameFor(int index, String namespace, TIntObjectMap<String> specialUseInfo, String fullName, String name, char sep, int type, int subscribe, BoolReference modified, BoolReference accountChanged) throws OXException {
         boolean isFullname = false == isEmpty(fullName);
         try {
             if (isFullname) {
                 // Check by specified desired full name
-                return doCheckFullNameFor(index, "", fullName, sep, type, subscribe, namespace, modified, accountChanged);
+                return doCheckFullNameFor(index, "", fullName, sep, type, subscribe, namespace, specialUseInfo, modified, accountChanged);
             }
             // Check by specified desired name
             if (isEmpty(name)) {
                 // Neither full name nor name
-                return doCheckFullNameFor(index, namespace, getFallbackName(index), sep, type, subscribe, namespace, modified, accountChanged);
+                return doCheckFullNameFor(index, namespace, getFallbackName(index), sep, type, subscribe, namespace, specialUseInfo, modified, accountChanged);
             }
-            return doCheckFullNameFor(index, namespace, name, sep, type, subscribe, namespace, modified, accountChanged);
+            return doCheckFullNameFor(index, namespace, name, sep, type, subscribe, namespace, specialUseInfo, modified, accountChanged);
         } catch (OXException e) {
             LOG.warn("Couldn't check default folder: {}. Namespace prefix: \"{}\"", (null == fullName ? (namespace + name) : fullName), (null == namespace ? "null" : namespace), e);
             e.setCategory(Category.CATEGORY_WARNING);
@@ -790,13 +893,14 @@ public class IMAPDefaultFolderChecker {
      * @param type The folder type
      * @param subscribe The subscribed flag
      * @param namespace The personal namespace prefix
+     * @param specialUseInfo The SPECIAL-USE information
      * @param modified Signals modified status
      * @param accountChanged The boolean reference to signal whether mail account has been changed
      * @return The checked full name
      * @throws MessagingException If a messaging error occurs
      * @throws OXException If an error occurs
      */
-    protected String doCheckFullNameFor(int index, String prefix, String qualifiedName, char sep, int type, int subscribe, String namespace, BoolReference modified, BoolReference accountChanged) throws MessagingException, OXException {
+    protected String doCheckFullNameFor(int index, String prefix, String qualifiedName, char sep, int type, int subscribe, String namespace, TIntObjectMap<String> specialUseInfo, BoolReference modified, BoolReference accountChanged) throws MessagingException, OXException {
         /*
          * Check default folder
          */
@@ -821,13 +925,16 @@ public class IMAPDefaultFolderChecker {
                     checkSpecialUseForExisting = true;
                 }
                 if (checkSpecialUseForExisting && hasMetadata && index <= StorageUtility.INDEX_TRASH && setSpecialUseForExisting()) {
-                    // E.g. SETMETADATA "SavedDrafts" (/private/specialuse "\\Drafts")
-                    String flag = SPECIAL_USES[index];
-                    try {
-                        IMAPCommandsCollection.setSpecialUses((IMAPFolder) imapStore.getFolder(desiredFullName), Collections.singletonList(flag));
-                        modified.setValue(true);
-                    } catch (Exception e) {
-                        LOG.debug("Failed to set {} flag for existing standard {} folder (full-name=\"{}\", namespace=\"{}\") for login {} (account={}) on IMAP server {} (user={}, context={})", flag, getFallbackName(index), desiredFullName, namespace, imapConfig.getLogin(), Integer.valueOf(accountId), imapConfig.getServer(), Integer.valueOf(session.getUserId()), Integer.valueOf(session.getContextId()), e);
+                    String specialUseFullName = specialUseInfo.get(index);
+                    if (false == desiredFullName.equals(specialUseFullName)) {
+                        // E.g. SETMETADATA "SavedDrafts" (/private/specialuse "\\Drafts")
+                        String flag = SPECIAL_USES[index];
+                        try {
+                            IMAPCommandsCollection.setSpecialUses((IMAPFolder) imapStore.getFolder(desiredFullName), Collections.singletonList(flag));
+                            modified.setValue(true);
+                        } catch (Exception e) {
+                            LOG.debug("Failed to set {} flag for existing standard {} folder (full-name=\"{}\", namespace=\"{}\") for login {} (account={}) on IMAP server {} (user={}, context={})", flag, getFallbackName(index), desiredFullName, namespace, imapConfig.getLogin(), Integer.valueOf(accountId), imapConfig.getServer(), Integer.valueOf(session.getUserId()), Integer.valueOf(session.getContextId()), e);
+                        }
                     }
                 }
                 return desiredFullName;
@@ -884,7 +991,7 @@ public class IMAPDefaultFolderChecker {
                     LOG.warn("Detected multiple existing IMAP folders with name equal ignore-case to \"{}\" for account {} (user={}, context={})", f.getName(), Integer.valueOf(accountId), Integer.valueOf(session.getUserId()), Integer.valueOf(session.getContextId()));
                 }
                 try {
-                    createIfNonExisting(f, type, sep, namespace, index);
+                    createIfNonExisting(f, type, sep, namespace, index, specialUseInfo);
                     checkSpecialUse = false;
                     modified.setValue(true);
                 } catch (MessagingException e) {
@@ -906,7 +1013,7 @@ public class IMAPDefaultFolderChecker {
                     if (!Strings.isEmpty(namespace) && !isFullNameLocatedInNamespace(desiredFullName, namespace, sep)) {
                         int sepPos = desiredFullName.lastIndexOf(sep);
                         String name = sepPos > 0 ? desiredFullName.substring(sepPos + 1) : desiredFullName;
-                        String checkedFullName = doCheckFullNameFor(index, "", namespace + name, sep, type, subscribe, namespace, modified, accountChanged);
+                        String checkedFullName = doCheckFullNameFor(index, "", namespace + name, sep, type, subscribe, namespace, specialUseInfo, modified, accountChanged);
                         clearAllAccountFullNames();
                         accountChanged.setValue(true);
                         return checkedFullName;
@@ -999,7 +1106,7 @@ public class IMAPDefaultFolderChecker {
      * @param index The index
      * @throws MessagingException If create attempt fails
      */
-    protected void createIfNonExisting(IMAPFolder f, int type, char sep, String namespace, int index) throws MessagingException {
+    protected void createIfNonExisting(IMAPFolder f, int type, char sep, String namespace, int index, TIntObjectMap<String> specialUseInfo) throws MessagingException {
         if (!f.exists()) {
             try {
                 IMAPCommandsCollection.createFolder(f, sep, type, false);
