@@ -121,6 +121,7 @@ final class ListLsubCollection implements Serializable {
     private final ConcurrentMap<String, ListLsubEntry> junkEntries;
     private final ConcurrentMap<String, ListLsubEntry> sentEntries;
     private final ConcurrentMap<String, ListLsubEntry> trashEntries;
+    private final ConcurrentMap<String, ListLsubEntry> archiveEntries;
 
     /**
      * Initializes a new {@link ListLsubCollection}.
@@ -141,6 +142,7 @@ final class ListLsubCollection implements Serializable {
         junkEntries = new ConcurrentHashMap<String, ListLsubEntry>();
         sentEntries = new ConcurrentHashMap<String, ListLsubEntry>();
         trashEntries = new ConcurrentHashMap<String, ListLsubEntry>();
+        archiveEntries = new ConcurrentHashMap<String, ListLsubEntry>();
         deprecated = new AtomicBoolean();
         this.shared = shared == null ? new String[0] : shared;
         this.user = user == null ? new String[0] : user;
@@ -166,6 +168,7 @@ final class ListLsubCollection implements Serializable {
         junkEntries = new ConcurrentHashMap<String, ListLsubEntry>();
         sentEntries = new ConcurrentHashMap<String, ListLsubEntry>();
         trashEntries = new ConcurrentHashMap<String, ListLsubEntry>();
+        archiveEntries = new ConcurrentHashMap<String, ListLsubEntry>();
         deprecated = new AtomicBoolean();
         this.shared = shared == null ? new String[0] : shared;
         this.user = user == null ? new String[0] : user;
@@ -217,6 +220,12 @@ final class ListLsubCollection implements Serializable {
             builder.append(lf).append("    ").append(entry);
         }
 
+        builder.append(lf).append("\\Archive:");
+        sm = new TreeMap<String, ListLsubEntry>(archiveEntries);
+        for (ListLsubEntry entry : sm.values()) {
+            builder.append(lf).append("    ").append(entry);
+        }
+
         return builder.toString();
     }
 
@@ -356,6 +365,7 @@ final class ListLsubCollection implements Serializable {
             junkEntries.clear();
             sentEntries.clear();
             trashEntries.clear();
+            archiveEntries.clear();
             if (imapStore.getCapabilities().containsKey("SPECIAL-USE")) {
                 /*
                  * Perform LIST (SPECIAL-USE) "" "*"
@@ -476,6 +486,7 @@ final class ListLsubCollection implements Serializable {
             junkEntries.clear();
             sentEntries.clear();
             trashEntries.clear();
+            archiveEntries.clear();
         } else if (ignoreSubscriptions) {
             lsubMap.clear();
         }
@@ -883,6 +894,7 @@ final class ListLsubCollection implements Serializable {
     private static final String ATTRIBUTE_JUNK = "\\junk";
     private static final String ATTRIBUTE_SENT = "\\sent";
     private static final String ATTRIBUTE_TRASH = "\\trash";
+    private static final String ATTRIBUTE_ARCHIVE = "\\archive";
 
     private static final String[] ATTRIBUTES_SPECIAL_USE = { ATTRIBUTE_DRAFTS, ATTRIBUTE_JUNK, ATTRIBUTE_SENT, ATTRIBUTE_TRASH };
 
@@ -917,6 +929,8 @@ final class ListLsubCollection implements Serializable {
                                 this.sentEntries.put(entryImpl.getFullName(), entryImpl);
                             } else if (attrs.contains(ATTRIBUTE_TRASH)) {
                                 this.trashEntries.put(entryImpl.getFullName(), entryImpl);
+                            } else if (attrs.contains(ATTRIBUTE_ARCHIVE)) {
+                                this.archiveEntries.put(entryImpl.getFullName(), entryImpl);
                             }
                         }
                     }
@@ -1017,6 +1031,8 @@ final class ListLsubCollection implements Serializable {
                             this.sentEntries.put(listLsubEntry.getFullName(), listLsubEntry);
                         } else if (attrs.contains(ATTRIBUTE_TRASH)) {
                             this.trashEntries.put(listLsubEntry.getFullName(), listLsubEntry);
+                        } else if (attrs.contains(ATTRIBUTE_ARCHIVE)) {
+                            this.archiveEntries.put(listLsubEntry.getFullName(), listLsubEntry);
                         }
                     }
                 }
@@ -1719,6 +1735,17 @@ final class ListLsubCollection implements Serializable {
         return Collections.unmodifiableCollection(trashEntries.values());
     }
 
+    /**
+     * Gets the LIST entries marked with "\Archive" attribute.
+     * <p>
+     * Needs the <code>"SPECIAL-USE"</code> capability.
+     *
+     * @return The entries
+     */
+    public Collection<ListLsubEntry> getArchiveEntry() {
+        return Collections.unmodifiableCollection(archiveEntries.values());
+    }
+
     /**
      * Gets the LIST entry for specified full name.
      *
@@ -1733,6 +1760,19 @@ final class ListLsubCollection implements Serializable {
         return listMap.get(fullName);
     }
 
+    /**
+     * Like {@link #getList(String)} but ignores if the collection is deprecated
+     *
+     * @param fullName The full name
+     * @return The LIST entry for specified full name or <code>null</code>
+     */
+    public ListLsubEntry getListIgnoreDeprecated(final String fullName) {
+        if (null == fullName) {
+            return null;
+        }
+        return listMap.get(fullName);
+    }
+
     /**
      * Gets the LSUB entry for specified full name.
      *
@@ -1747,6 +1787,19 @@ final class ListLsubCollection implements Serializable {
         return lsubMap.get(fullName);
     }
 
+    /**
+     * Like {@link #getLsub(String))} but ignores if the collection is deprecated.
+     *
+     * @param fullName The full name
+     * @return The LSUB entry for specified full name or <code>null</code>
+     */
+    public ListLsubEntry getLsubIgnoreDeprecated(final String fullName) {
+        if (null == fullName) {
+            return null;
+        }
+        return lsubMap.get(fullName);
+    }
+
     /**
      * Gets the LSUB entries.
      *
@@ -1757,6 +1810,15 @@ final class ListLsubCollection implements Serializable {
         return new ArrayList<ListLsubEntry>(lsubMap.values());
     }
 
+    /**
+     * Like {@link #getLsubs()} but ignores if the collection is deprecated
+     *
+     * @return The LSUB entries
+     */
+    public List<ListLsubEntry> getLsubsIgnoreDeprecated() {
+        return new ArrayList<ListLsubEntry>(lsubMap.values());
+    }
+
     /**
      * Gets the LIST entries.
      *
@@ -1767,6 +1829,15 @@ final class ListLsubCollection implements Serializable {
         return new ArrayList<ListLsubEntry>(listMap.values());
     }
 
+    /**
+     * Like {@link #getLists()} but ignores if the collection is deprecated
+     *
+     * @return The LIST entries
+     */
+    public List<ListLsubEntry> getListsIgnoreDeprecated() {
+        return new ArrayList<ListLsubEntry>(listMap.values());
+    }
+
 
     private static final TObjectIntHashMap<String> POS_MAP;
 
