@@ -246,10 +246,10 @@ public final class IMAPMailPart extends MailPart implements MimeRawSource, Conne
             if (null != bodystructure.type || null != bodystructure.subtype || null != cParams) {
                 final ContentType contentType = new ContentType();
                 if (null != bodystructure.type) {
-                    contentType.setPrimaryType(toLowerCase(bodystructure.type));
+                    contentType.setPrimaryType(com.openexchange.java.Strings.toLowerCase(bodystructure.type));
                 }
                 if (null != bodystructure.subtype) {
-                    contentType.setSubType(toLowerCase(bodystructure.subtype));
+                    contentType.setSubType(com.openexchange.java.Strings.toLowerCase(bodystructure.subtype));
                 }
                 if (null != cParams) {
                     for (final Enumeration<?> names = cParams.getNames(); names.hasMoreElements();) {
@@ -280,20 +280,6 @@ public final class IMAPMailPart extends MailPart implements MimeRawSource, Conne
         }
     }
 
-    /** ASCII-wise to lower-case */
-    private static String toLowerCase(final CharSequence chars) {
-        if (null == chars) {
-            return null;
-        }
-        final int length = chars.length();
-        final StringBuilder builder = new StringBuilder(length);
-        for (int i = 0; i < length; i++) {
-            final char c = chars.charAt(i);
-            builder.append((c >= 'A') && (c <= 'Z') ? (char) (c ^ 0x20) : c);
-        }
-        return builder.toString();
-    }
-
     @Override
     public void opened(final ConnectionEvent e) {
         // Ignore
