@@ -51,6 +51,10 @@ package com.openexchange.imap.sort;
 
 import static com.openexchange.imap.util.ImapUtility.prepareImapCommandForLogging;
 import static com.openexchange.mail.MailServletInterface.mailInterfaceMonitor;
+import gnu.trove.list.TIntList;
+import gnu.trove.list.TLongList;
+import gnu.trove.list.array.TIntArrayList;
+import gnu.trove.list.array.TLongArrayList;
 import java.io.IOException;
 import java.util.EnumMap;
 import java.util.Map;
@@ -79,15 +83,10 @@ import com.sun.mail.iap.ProtocolException;
 import com.sun.mail.iap.Response;
 import com.sun.mail.imap.IMAPFolder;
 import com.sun.mail.imap.IMAPFolder.ProtocolCommand;
-import com.sun.mail.imap.IMAPStore;
 import com.sun.mail.imap.SortTerm;
 import com.sun.mail.imap.protocol.IMAPProtocol;
 import com.sun.mail.imap.protocol.IMAPResponse;
 import com.sun.mail.imap.protocol.SearchSequence;
-import gnu.trove.list.TIntList;
-import gnu.trove.list.TLongList;
-import gnu.trove.list.array.TIntArrayList;
-import gnu.trove.list.array.TLongArrayList;
 
 /**
  * {@link IMAPSort} - Perform the IMAP sort.
@@ -169,10 +168,11 @@ public final class IMAPSort {
                     final int[] seqNums;
                     {
                         // Do IMAP sort
-                        final long start = System.currentTimeMillis();
+                        long start = System.currentTimeMillis();
                         seqNums = IMAPCommandsCollection.getServerSortList(imapFolder, sortCriteria, filter);
-                        mailInterfaceMonitor.addUseTime(System.currentTimeMillis() - start);
-                        LOG.debug("IMAP sort took {}msec", (System.currentTimeMillis() - start));
+                        long duration = System.currentTimeMillis() - start;
+                        mailInterfaceMonitor.addUseTime(duration);
+                        LOG.debug("IMAP sort took {}msec", duration);
                     }
                     if ((seqNums == null) || (seqNums.length == 0)) {
                         return new int[0];
