@@ -50,13 +50,11 @@
 package com.openexchange.imap.storecache;
 
 import static com.openexchange.imap.IMAPAccess.doIMAPConnect;
-import java.util.LinkedHashMap;
-import java.util.Map;
 import javax.mail.AuthenticationFailedException;
 import javax.mail.MessagingException;
 import com.openexchange.imap.IMAPClientParameters;
+import com.openexchange.log.LogProperties;
 import com.openexchange.session.Session;
-import com.openexchange.version.Version;
 import com.sun.mail.imap.IMAPStore;
 
 /**
@@ -104,7 +102,22 @@ public abstract class AbstractIMAPStoreContainer implements IMAPStoreContainer {
         /*
          * ... and connect it
          */
-        doIMAPConnect(imapSession, imapStore, server, port, login, pw);
+        try {
+            doIMAPConnect(imapSession, imapStore, server, port, login, pw);
+        } catch (final AuthenticationFailedException e) {
+            /*
+             * Retry connect with AUTH=PLAIN disabled
+             */
+            imapSession.getProperties().put("mail.imap.auth.login.disable", "true");
+            imapStore = (IMAPStore) imapSession.getStore(name);
+            doIMAPConnect(imapSession, imapStore, server, port, login, pw);
+        }
+
+        String sessionInformation = imapStore.getClientParameter(IMAPClientParameters.SESSION_ID.getParamName());
+        if (null != sessionInformation) {
+            LogProperties.put(LogProperties.Name.MAIL_SESSION, sessionInformation);
+        }
+
         return imapStore;
     }
 
